searchData={"items":[{"type":"module","title":"Soothsayer","doc":"","ref":"Soothsayer.html"},{"type":"function","title":"Soothsayer.fit/2","doc":"","ref":"Soothsayer.html#fit/2"},{"type":"function","title":"Soothsayer.new/1","doc":"","ref":"Soothsayer.html#new/1"},{"type":"function","title":"Soothsayer.predict/2","doc":"","ref":"Soothsayer.html#predict/2"},{"type":"function","title":"Soothsayer.predict_components/2","doc":"","ref":"Soothsayer.html#predict_components/2"},{"type":"module","title":"Soothsayer.Model","doc":"","ref":"Soothsayer.Model.html"},{"type":"function","title":"Soothsayer.Model.build_network/1","doc":"","ref":"Soothsayer.Model.html#build_network/1"},{"type":"function","title":"Soothsayer.Model.fit/4","doc":"","ref":"Soothsayer.Model.html#fit/4"},{"type":"function","title":"Soothsayer.Model.new/1","doc":"","ref":"Soothsayer.Model.html#new/1"},{"type":"function","title":"Soothsayer.Model.predict/2","doc":"","ref":"Soothsayer.Model.html#predict/2"},{"type":"module","title":"Soothsayer.Preprocessor","doc":"","ref":"Soothsayer.Preprocessor.html"},{"type":"function","title":"Soothsayer.Preprocessor.prepare_data/4","doc":"","ref":"Soothsayer.Preprocessor.html#prepare_data/4"},{"type":"extras","title":"Soothsayer","doc":"# Soothsayer\n\nSoothsayer is an Elixir library for time series forecasting, inspired by Facebook's Prophet and NeuralProphet. It provides a flexible and easy-to-use interface for creating and training forecasting models.\n\n**Warning:** Soothsayer is currently in alpha stage. The API is unstable and may change at any moment without prior notice. Use with caution in production environments.","ref":"readme.html"},{"type":"extras","title":"Installation - Soothsayer","doc":"Add `soothsayer` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:soothsayer, \"~> 0.1.0\"},\n  ]\nend\n```\n\nThen run `mix deps.get` to install the dependencies.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Soothsayer","doc":"Here's a basic example of how to use Soothsayer:\n\n```elixir\nalias Explorer.DataFrame\nalias Explorer.Series\n\n# Create sample data, (or use your own data)\ndates = Date.range(~D[2020-01-01], ~D[2022-12-31])\ny = Enum.map(dates, fn date ->\n  day_of_year = Date.day_of_year(date)\n  trend = 100 + 0.1 * Date.diff(date, ~D[2020-01-01])\n  seasonality = 10 * :math.sin(2 * :math.pi * day_of_year / 365.25)\n  trend + seasonality + :rand.normal(0, 5)\nend)\n\ndf = DataFrame.new(%{\n  \"ds\" => dates,\n  \"y\" => y\n})\n\n# Create and fit the model\nmodel = Soothsayer.new()\nfitted_model = Soothsayer.fit(model, df)\n\n# Make predictions\nfuture_dates = Date.range(~D[2023-01-01], ~D[2023-12-31])\npredictions = Soothsayer.predict(fitted_model, Series.from_list(Enum.to_list(future_dates)))\n\n# Print the predictions\nIO.inspect(predictions)\n```\n\nYou can also get the components of the forecast:\n\n```elixir\ncomponents = Soothsayer.predict_components(fitted_model, Series.from_list(Enum.to_list(future_dates)))\n\n#> %{comboned: ..., trend: ..., yearly_seasonality: ..., weekly_seasonality: ...}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Customizing the Model - Soothsayer","doc":"You can customize various aspects of the model:\n\n```elixir\nmodel = Soothsayer.new(%{\n  trend: %{enabled: true},\n  seasonality: %{\n    yearly: %{enabled: true, fourier_terms: 10},\n    weekly: %{enabled: false}\n  },\n  epochs: 200,\n  learning_rate: 0.005\n})\n```","ref":"readme.html#customizing-the-model"},{"type":"extras","title":"Using EXLA for Faster Training - Soothsayer","doc":"Soothsayer can use EXLA (Elixir XLA) for faster training, but it's not the default backend. To use EXLA:\n\n1. Make sure you've added EXLA to your dependencies as shown in the Installation section.\n\n2. Set EXLA as the default backend for Nx. Add the following to your `config/config.exs` file:\n\n   ```elixir\n   config :nx, default_backend: EXLA.Backend\n   ```\n\n   Alternatively, you can set it at runtime before using Soothsayer:\n\n   ```elixir\n   Nx.global_default_backend(EXLA.Backend)\n   ```","ref":"readme.html#using-exla-for-faster-training"},{"type":"extras","title":"Differences from NeuralProphet - Soothsayer","doc":"Soothsayer is inspired by NeuralProphet but implemented in Elixir with some key differences:\n\n1. **Elixir Ecosystem**: Soothsayer is built using Elixir and leverages libraries like Explorer for data manipulation and Axon for neural networks.\n\n2. **Simplified Model**: Soothsayer currently offers a more streamlined model with fewer components, focusing on trend and seasonality.\n\n3. **Data Handling**: Soothsayer uses Explorer's DataFrame for data manipulation, which may have different performance characteristics compared to pandas.\n\n4. **Training Process**: The training process in Soothsayer is implemented using Axon and may differ in some aspects from NeuralProphet's PyTorch implementation.","ref":"readme.html#differences-from-neuralprophet"},{"type":"extras","title":"Features Not Yet Implemented - Soothsayer","doc":"Soothsayer is a work in progress. The following NeuralProphet features are not yet implemented:\n\n- Auto Regression\n- Lagged Regressors\n- Future Regressors\n- Events and Holidays\n- Uncertainty Estimation\n- Global and Local Models (models based on geography)\n- Multiplicative Seasonality (currently only additive is supported)\n- Piecewise Linear Trends (currently only simple linear trend is supported)\n- Advanced Regularization Options\n- Automatic Changepoint Detection\n- Cross-Validation and Hyperparameter Tuning\n\nWe plan to implement some of these features in future versions of Soothsayer.","ref":"readme.html#features-not-yet-implemented"},{"type":"extras","title":"Contributing - Soothsayer","doc":"Contributions are welcome! Please feel free to submit a Pull Request.","ref":"readme.html#contributing"},{"type":"extras","title":"License - Soothsayer","doc":"Soothsayer is released under the Apache License 2.0. See the LICENSE file for details.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}